@@ -1,7 +1,7 @@
 package Acme::CPANLists;
 
 our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.90.5'; # VERSION
+our $VERSION = '0.90.6'; # VERSION
 
 1;
 # ABSTRACT: CPAN lists
@@ -18,7 +18,7 @@ Acme::CPANLists - CPAN lists
 
 =head1 VERSION
 
-This document describes version 0.90.5 of Acme::CPANLists (from Perl distribution Acme-CPANLists), released on 2016-12-28.
+This document describes version 0.90.6 of Acme::CPANLists (from Perl distribution Acme-CPANLists), released on 2016-12-28.
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,10 @@ get to it :-), or perhaps when I get some help).
 The first step is to decide on a name of the module. It must be under the
 C<Acme::CPANLists::> namespace. Since, unlike in Acme::CPANAuthors, a module can
 contain multiple lists, you can just use your CPAN ID for the module, even if
-you want to create many lists, for example: L<Acme::CPANLists::PERLANCAR>.
+you want to create many lists, for example: L<Acme::CPANLists::PERLANCAR>. But I
+recommend that you put each list into a separate module under your CPAN ID
+subpackage, for example: L<Acme::CPANLists::PERLANCAR::Unbless> or
+L<Acme::CPANLists::PERLANCAR::Task::PickingRandomLinesFromFile>.
 
 Inside the module, the two main package variables you have to declare are:
 
